==> bayesm_2.0-2.tar.gz: bayesm/man/rsurGibbs.Rd <==
\name{rsurGibbs}
\alias{rsurGibbs}
\concept{bayes}
\concept{Gibbs Sampler}
\concept{regression}
\concept{SUR model}
\concept{Seemingly Unrelated Regression}
\concept{MCMC}

\title{ Gibbs Sampler for Seemingly Unrelated Regressions (SUR) }
\description{
 \code{rsurGibbs} implements a Gibbs Sampler to draw from the posterior of the Seemingly Unrelated
  Regression (SUR) Model of Zellner
}
\usage{
rsurGibbs(Data, Prior, Mcmc)
}
\arguments{
  \item{Data}{ list(regdata)}
  \item{Prior}{ list(betabar,A, nu, V) }
  \item{Mcmc}{ list(R,keep)}
}
\details{
  Model: \eqn{y_i = X_ibeta_i + e_i}.  i=1,\ldots,m. m regressions. \cr
  (e(1,k), \ldots, e(m,k)) \eqn{\sim}{~} \eqn{N(0,Sigma)}. k=1, \ldots, nobs. 

  We can also write as the stacked model: \cr
  \eqn{y = Xbeta + e} where y is a nobs*m long vector and k=length(beta)=sum(length(betai)).

  Note: we must have the same number of observations in each equation but we can have different numbers
  of X variables 

  Priors: \eqn{beta} \eqn{\sim}{~} \eqn{N(betabar,A^{-1})}.  \eqn{Sigma} \eqn{\sim}{~} \eqn{IW(nu,V)}.

  List arguments contain  
  \itemize{
    \item{\code{regdata}}{list of lists, regdata[[i]]=list(y=yi,X=Xi)}
    \item{\code{betabar}}{k x 1 prior mean (def: 0)}
    \item{\code{A}}{k x k prior precision matrix (def: .01I)} 
    \item{\code{nu}}{ d.f. parm for Inverted Wishart prior (def: m+3)}
    \item{\code{V}}{ scale parm for Inverted Wishart prior (def: nu*I)}
    \item{\code{R}}{ number of MCMC draws }
    \item{\code{keep}}{ thinning parameter - keep every keepth draw }
  }
}
\value{
  list of MCMC draws
  \item{betadraw }{ R x k array of betadraws }
  \item{Sigmadraw }{ R x (m*m) array of Sigma draws}
}
\references{ For further discussion, see \emph{Bayesian Statistics and Marketing}
  by Rossi, Allenby and McCulloch, Chapter 3. \cr
  \url{http://gsbwww.uchicago.edu/fac/peter.rossi/research/bsm.html}
}

\author{ Peter Rossi, Graduate School of Business, University of Chicago,
  \email{Peter.Rossi@ChicagoGsb.edu}.
}

\seealso{ \code{\link{rmultireg}} }

\examples{
if(nchar(Sys.getenv("LONG_TEST")) != 0) {R=1000} else {R=10}
##
## simulate data from SUR
set.seed(66)
beta1=c(1,2)
beta2=c(1,-1,-2)
nobs=100
nreg=2
iota=c(rep(1,nobs))
X1=cbind(iota,runif(nobs))
X2=cbind(iota,runif(nobs),runif(nobs))
Sigma=matrix(c(.5,.2,.2,.5),ncol=2)
U=chol(Sigma)
E=matrix(rnorm(2*nobs),ncol=2)%*%U
y1=X1\%*\%beta1+E[,1]
y2=X2\%*\%beta2+E[,2]
##
## run Gibbs Sampler
regdata=NULL
regdata[[1]]=list(y=y1,X=X1)
regdata[[2]]=list(y=y2,X=X2)
Mcmc=list(R=R)
out=rsurGibbs(Data=list(regdata=regdata),Mcmc=Mcmc)
##
## summarize GS output
if(R < 100) {begin=1} else {begin=100}
end=Mcmc$R
cat(" betadraws ",fill=TRUE)
mat=apply(out$betadraw[begin:end,],2,quantile,probs=c(.01,.05,.5,.95,.99))
mat=rbind(c(beta1,beta2),mat); rownames(mat)[1]="beta"; print(mat)
cat(" Sigmadraws ",fill=TRUE)
mat=apply(out$Sigmadraw[begin:end,],2,quantile,probs=c(.01,.05,.5,.95,.99))
mat=rbind(as.vector(Sigma),mat); rownames(mat)[1]="sigma"; print(mat)
}

\keyword{ regression}

==> bayesm_2.0-9.tar.gz: bayesm/man/rsurGibbs.Rd <==
\name{rsurGibbs}
\alias{rsurGibbs}
\concept{bayes}
\concept{Gibbs Sampler}
\concept{regression}
\concept{SUR model}
\concept{Seemingly Unrelated Regression}
\concept{MCMC}

\title{ Gibbs Sampler for Seemingly Unrelated Regressions (SUR) }
\description{
 \code{rsurGibbs} implements a Gibbs Sampler to draw from the posterior of the Seemingly Unrelated
  Regression (SUR) Model of Zellner
}
\usage{
rsurGibbs(Data, Prior, Mcmc)
}
\arguments{
  \item{Data}{ list(regdata)}
  \item{Prior}{ list(betabar,A, nu, V) }
  \item{Mcmc}{ list(R,keep)}
}
\details{
  Model: \eqn{y_i = X_ibeta_i + e_i}.  i=1,\ldots,m. m regressions. \cr
  (e(1,k), \ldots, e(m,k)) \eqn{\sim}{~} \eqn{N(0,Sigma)}. k=1, \ldots, nobs. 

  We can also write as the stacked model: \cr
  \eqn{y = Xbeta + e} where y is a nobs*m long vector and k=length(beta)=sum(length(betai)).

  Note: we must have the same number of observations in each equation but we can have different numbers
  of X variables 

  Priors: \eqn{beta} \eqn{\sim}{~} \eqn{N(betabar,A^{-1})}.  \eqn{Sigma} \eqn{\sim}{~} \eqn{IW(nu,V)}.

  List arguments contain  
  \itemize{
    \item{\code{regdata}}{list of lists, regdata[[i]]=list(y=yi,X=Xi)}
    \item{\code{betabar}}{k x 1 prior mean (def: 0)}
    \item{\code{A}}{k x k prior precision matrix (def: .01I)} 
    \item{\code{nu}}{ d.f. parm for Inverted Wishart prior (def: m+3)}
    \item{\code{V}}{ scale parm for Inverted Wishart prior (def: nu*I)}
    \item{\code{R}}{ number of MCMC draws }
    \item{\code{keep}}{ thinning parameter - keep every keepth draw }
  }
}
\value{
  list of MCMC draws
  \item{betadraw }{ R x k array of betadraws }
  \item{Sigmadraw }{ R x (m*m) array of Sigma draws}
}
\references{ For further discussion, see \emph{Bayesian Statistics and Marketing}
  by Rossi, Allenby and McCulloch, Chapter 3. \cr
  \url{http://faculty.chicagogsb.edu/peter.rossi/research/bsm.html}
}

\author{ Peter Rossi, Graduate School of Business, University of Chicago,
  \email{Peter.Rossi@ChicagoGsb.edu}.
}

\seealso{ \code{\link{rmultireg}} }

\examples{
if(nchar(Sys.getenv("LONG_TEST")) != 0) {R=1000} else {R=10}
##
## simulate data from SUR
set.seed(66)
beta1=c(1,2)
beta2=c(1,-1,-2)
nobs=100
nreg=2
iota=c(rep(1,nobs))
X1=cbind(iota,runif(nobs))
X2=cbind(iota,runif(nobs),runif(nobs))
Sigma=matrix(c(.5,.2,.2,.5),ncol=2)
U=chol(Sigma)
E=matrix(rnorm(2*nobs),ncol=2)%*%U
y1=X1\%*\%beta1+E[,1]
y2=X2\%*\%beta2+E[,2]
##
## run Gibbs Sampler
regdata=NULL
regdata[[1]]=list(y=y1,X=X1)
regdata[[2]]=list(y=y2,X=X2)
Mcmc=list(R=R)
out=rsurGibbs(Data=list(regdata=regdata),Mcmc=Mcmc)
##
## summarize GS output
if(R < 100) {begin=1} else {begin=100}
end=Mcmc$R
cat(" betadraws ",fill=TRUE)
mat=apply(out$betadraw[begin:end,],2,quantile,probs=c(.01,.05,.5,.95,.99))
mat=rbind(c(beta1,beta2),mat); rownames(mat)[1]="beta"; print(mat)
cat(" Sigmadraws ",fill=TRUE)
mat=apply(out$Sigmadraw[begin:end,],2,quantile,probs=c(.01,.05,.5,.95,.99))
mat=rbind(as.vector(Sigma),mat); rownames(mat)[1]="sigma"; print(mat)
}

\keyword{ regression}
